@@ -1,10 +1,10 @@
-from .browser import Browser
+from .chromium import ChromiumHeadless
 from .search_utils import get_command_origin, find_first_defined_env_var
 
 import subprocess
-import platform
 import os
 import shutil
+import platform
 
 ENV_VAR_LOOKUP_TOGGLE = 'HTML2IMAGE_TOGGLE_ENV_VAR_LOOKUP'
 
@@ -15,7 +15,6 @@ CHROME_EXECUTABLE_ENV_VAR_CANDIDATES = [
     'CHROME_EXE',
 ]
 
-
 def _find_chrome(user_given_executable=None):
     """ Finds a Chrome executable.
 
@@ -115,7 +114,8 @@ def _find_chrome(user_given_executable=None):
             'chromium',
             'chromium-browser',
             'chrome',
-            'google-chrome'
+            'google-chrome',
+            'google-chrome-stable'
         ]
 
         for chrome_command in chrome_commands:
@@ -161,8 +161,7 @@ def _find_chrome(user_given_executable=None):
         'machine, please specify it yourself.'
     )
 
-
-class ChromeHeadless(Browser):
+class ChromeHeadless(ChromiumHeadless):
     """
         Chrome/Chromium browser wrapper.
 
@@ -174,23 +173,20 @@ class ChromeHeadless(Browser):
         - `flags` : list of str
             + Flags to be used by the headless browser.
             + Default flags are :
-                - '--default-background-color=000000'
+                - '--default-background-color=00000000'
                 - '--hide-scrollbars'
         - `print_command` : bool
             + Whether or not to print the command used to take a screenshot.
+        - `disable_logging` : bool
+            + Whether or not to disable Chrome's output.
+        - `use_new_headless` : bool, optional
+            + Whether or not to use the new headless mode.
+            + By default, the old headless mode is used.
+            + You can also keep the original behavior to backward compatibility by setting this to `None`.
     """
 
-    def __init__(self, executable=None, flags=None, print_command=False):
-        self.executable = executable
-        if not flags:
-            self.flags = [
-                '--default-background-color=000000',
-                '--hide-scrollbars',
-            ]
-        else:
-            self.flags = [flags] if isinstance(flags, str) else flags
-
-        self.print_command = print_command
+    def __init__(self, executable=None, flags=None, print_command=False, disable_logging=False, use_new_headless=False,):
+        super().__init__(executable=executable, flags=flags, print_command=print_command, disable_logging=disable_logging, use_new_headless=use_new_headless)
 
     @property
     def executable(self):
@@ -199,58 +195,3 @@ class ChromeHeadless(Browser):
     @executable.setter
     def executable(self, value):
         self._executable = _find_chrome(value)
-
-    def screenshot(
-        self,
-        input,
-        output_path,
-        output_file='screenshot.png',
-        size=(1920, 1080),
-    ):
-        """ Calls Chrome or Chromium headless to take a screenshot.
-
-            Parameters
-            ----------
-            - `output_file`: str
-                + Name as which the screenshot will be saved.
-                + File extension (e.g. .png) has to be included.
-                + Default is screenshot.png
-            - `input`: str
-                + File or url that will be screenshotted.
-                + Cannot be None
-            - `size`: (int, int), optional
-                + Two values representing the window size of the headless
-                + browser and by extention, the screenshot size.
-                + These two values must be greater than 0.
-            Raises
-            ------
-            - `ValueError`
-                + If the value of `size` is incorrect.
-                + If `input` is empty.
-        """
-
-        if not input:
-            raise ValueError('The `input` parameter is empty.')
-
-        if size[0] < 1 or size[1] < 1:
-            raise ValueError(
-                f'Could not screenshot "{output_file}" '
-                f'with a size of {size}:\n'
-                'A valid size consists of two integers greater than 0.'
-            )
-
-        # command used to launch chrome in
-        # headless mode and take a screenshot
-        command = [
-            f'{self.executable}',
-            '--headless',
-            f'--screenshot={os.path.join(output_path, output_file)}',
-            f'--window-size={size[0]},{size[1]}',
-            *self.flags,
-            f'{input}',
-        ]
-
-        if self.print_command:
-            print(' '.join(command))
-
-        subprocess.run(command)
